==> haskell-hjsonschema-1.9.0-223-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.9.0
id: hjsonschema-1.9.0-GaY9PsePh7AH3bTlFTD5gN
key: hjsonschema-1.9.0-GaY9PsePh7AH3bTlFTD5gN
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
abi: 6e7044e663eb0067d082d70dd276e2c9
exposed: True
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
import-dirs: /usr/lib/ghc-8.6.5/site-local/hjsonschema-1.9.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hjsonschema-1.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hjsonschema-1.9.0
hs-libraries: HShjsonschema-1.9.0-GaY9PsePh7AH3bTlFTD5gN
depends:
    QuickCheck-2.13.1-7krqagqcRmA9RWDtUhyOg8
    aeson-1.4.3.0-3QzK2ng22UC3SLyLfNCRqk base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsonpointer-1.5.0-Dt7ZsnR2oV0GRmt2yEmOTB
    http-client-0.6.4-LXiPJxPJFMpGi3JM63704B
    http-client-tls-0.3.5.3-7eC0pgkJ2fX6rTJw40cpRM
    http-types-0.12.3-1S9CCheq0oP9PZghw2BQoa
    pcre-heavy-1.0.0.2-LOcRFdecSZN6odDALBhMpl
    profunctors-5.4-Hkj445FiweuBattm2piECo
    protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
    safe-exceptions-0.1.7.0-I4EpfcxGxCuJFZhieWPQVZ
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonschema-1.9.0-225-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.9.0
id: hjsonschema-1.9.0-K9qXfXW1AtP6HeV8M5K8w2
key: hjsonschema-1.9.0-K9qXfXW1AtP6HeV8M5K8w2
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
abi: 204f2c5039a641a08ee5c0d5f4999913
exposed: True
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
import-dirs: /usr/lib/ghc-8.6.5/site-local/hjsonschema-1.9.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hjsonschema-1.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hjsonschema-1.9.0
hs-libraries: HShjsonschema-1.9.0-K9qXfXW1AtP6HeV8M5K8w2
depends:
    QuickCheck-2.13.1-7krqagqcRmA9RWDtUhyOg8
    aeson-1.4.3.0-3QzK2ng22UC3SLyLfNCRqk base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsonpointer-1.5.0-Dt7ZsnR2oV0GRmt2yEmOTB
    http-client-0.6.4-LXiPJxPJFMpGi3JM63704B
    http-client-tls-0.3.5.3-IRmndMfSCpqG3rjGb9VOHe
    http-types-0.12.3-1S9CCheq0oP9PZghw2BQoa
    pcre-heavy-1.0.0.2-LOcRFdecSZN6odDALBhMpl
    profunctors-5.4-Hkj445FiweuBattm2piECo
    protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
    safe-exceptions-0.1.7.0-I4EpfcxGxCuJFZhieWPQVZ
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
